/*---------- REXX Macro: FILEOUT ------------------------------------*/ 
/*                                                                   */ 
/*  This ISREDIT MACRO will read through a MVS Job's JCL and         */ 
/*  show the user the files that are assigned to SYSOUT.  It will    */ 
/*  ask the user to identify which files should be sent out to a     */ 
/*  disk file.  It will then modify the JCL to include the necessary */ 
/*  DD statements and will insert an additional step at the start    */ 
/*  of the job to delete those files before processing.              */ 
/*                                                                   */ 
/*  The user may then EDIT the JCL to customize it to his/her needs. */ 
/*                                                                   */ 
/*  PARAMETER(s):   NONE                                             */ 
/*                                                                   */ 
/*  RESULT_CODES:   NONE                                             */ 
/*                                                                   */ 
/*-------------------------------------------------------------------*/ 

TRACE N 
ADDRESS ISREDIT 
"MACRO" 

/*-------------------------------------------------------------------*/ 
/*   Initialize working variables                                    */ 
/*-------------------------------------------------------------------*/ 
ftbl.  = '' 
fcount = 0 

/*------------------------------------------------------------------*/ 
/*  Verify that this Dataset is MVS JCL                             */ 
/*------------------------------------------------------------------*/ 
"(xline) = LINE 1" 
IF INDEX(xline, ' JOB ') = 0 THEN EXIT  /* Skip if not JOB Statement*/ 

/*-------------------------------------------------------------------*/ 
/*   Find files that are SYSOUT and Store them in the 'ftbl' array   */ 
/*-------------------------------------------------------------------*/ 
"(fline) = LINENUM .ZFIRST" 
"(lline) = LINENUM .ZLAST" 
DO i = fline TO lline 
   "(xline) = LINE" i 
   IF INDEX(xline, ' DD ') > 0 THEN DO 
      IF INDEX(xline, 'SYSOUT=') > 0 THEN DO 
         fcount = fcount + 1 
         PARSE VAR xline '//' ftbl.fcount.ddname ' DD ' . 
         ftbl.fcount.lineno = i 
         END 
      END 
   END 
IF fcount = 0 THEN 
   EXIT               /* No Files are SYSOUT(s) */ 

ADDRESS TSO "CLEAR" 
SAY "Convert SYSOUT DD Statements to Datasets:" 
DO i = 1 to fcount 
   SAY "   "i") "ftbl.i.ddname 
   END 
SAY "" 
SAY "Select one or more by its number:" 
ADDRESS TSO "NEWSTACK" 
PULL selectdd 
ADDRESS TSO "DELSTACK" 
IF selectdd = "" THEN 
   EXIT        /* No files requested */ 

/*------------------------------------------------------------------*/ 
/*  Insert new DD statement into JCL                                */ 
/*------------------------------------------------------------------*/ 
DO i = fcount TO 1 BY -1 
   IF INDEX(selectdd, i) > 0 THEN DO 
      dsn.i = USERID()".SYSOUT."SPACE(ftbl.i.ddname) 
      ddn.i = LEFT(ftbl.i.ddname"        ", 8) 
      "LINE "ftbl.i.lineno" = '//"ddn.i" DD DSN="dsn.i",'" 
      lno = "LINE_AFTER "ftbl.i.lineno" = " 
      lno"'//            UNIT=SYSDA,SPACE=(TRK,(1,1),RLSE)'" 
      lno"'//            DCB=(LRECL=512,RECFM=VB,BLKSIZE=32000),'" 
      lno"'//            DISP=(NEW,CATLG,DELETE),'" 
      END 
   END 

/*------------------------------------------------------------------*/ 
/*  Insert File Delete job step to delete inserted datasets         */ 
/*    before execution                                              */ 
/*------------------------------------------------------------------*/ 
DO i = fline TO lline 
   "(xline) = LINE " i        /* Find First EXEC Statement */ 
   IF INDEX(xline, ' EXEC ') <> 0 THEN 
      LEAVE 
   END 

i = i - 1 
lno = "LINE_AFTER "i" = " 
lno"'//*'" 
DO i = fcount TO 1 BY -1 
   IF INDEX(selectdd, i) > 0 THEN DO 
      lno"'//            UNIT=SYSDA,SPACE=(TRK,1)'" 
      lno"'//            DISP=(MOD,DELETE,DELETE),'" 
      lno"'//"ddn.i" DD DSN="dsn.i",'" 
      END 
   END 
lno"'//DELETE   EXEC PGM=IEFBR14'" 
lno"'//*'" 

EXIT 
