/*------  REXX: SplitPDS ------------------------------------*/ 
/*                                                           */ 
/*     This procedure will take a sequential text file and   */ 
/*  split it into several members in a Partitioned Dataset   */ 
/*  (PDS).  The key to splitting these files is a line of    */ 
/*  text containing '$$$pdsnamex$$$', where "pdsnamex" is    */ 
/*  the name of the member where data is to be stored.       */ 
/*                                                           */ 
/*     This procedure requires two parameters to run:        */ 
/*  (1)  Input File Name                                     */ 
/*  (2)  Destination PDS Name                                */ 
/*                                                           */ 
/*                                                           */ 
/*-----------------------------------------------------------*/ 

TRACE N 

ADDRESS TSO 
ARG iFileName oFileName . 

IF oFileName = '' THEN DO 
   "CLEAR" 
   DO I = 1 TO 50 
      IF SourceLine(I) = "TRACE N" THEN 
         EXIT; 
      SAY STRIP(SourceLine(I)) 
      END 
   END 

IF LISTDSI(iFileName) <> 0 THEN DO 
   SAY "Invalid Input File Name in Parameter #1" 
   EXIT 
   END 
IF LISTDSI(oFileName) <> 0 THEN DO 
   SAY "Invalid Output PDS File Name in Parameter #2" 
   EXIT 
   END 

"ALLOC DDN(iFile) SHR DSN("iFileName") REUSE" 
"EXECIO * DISKR iFile (STEM Line. FINIS)" 
"FREE  DDN(iFile)" 

"ALLOC DDN(oFile) SHR DSN(*) REUSE" 
DO I = 1 TO Line.0 
  IF LEFT(Line.I, 4) = "$$$$" THEN DO 
     "EXECIO "QUEUED()" DISKW oFile (FINIS)" 
     PARSE VAR Line.I "$$$$" Member "$$$$" . 
     "ALLOC DDN(oFile) SHR DSN("oFileName"("Member")) REUSE" 
     END 
  ELSE 
     QUEUE Line.I 
  END 

"EXECIO "QUEUED()" DISKW oFile (FINIS)" 
"FREE DDN(oFile)" 
