/*----- REXX: SQL$HOG --------------------------------------------------*/ 
/*                                                                      */ 
/*  This process reads a dataset specified in Parameter#1 that has      */ 
/*  the output from the SQL$HOG query. The comments are parsed out      */ 
/*  into separate lines and the StatementText (SQL Statements) are      */ 
/*  broken into separate lines based upon the LF (Hex '0D') characters  */ 
/*  found in the Text.                                                  */ 
/*                                                                      */ 
/*  The output will be written into the dataset specified in            */ 
/*  Parameter#2.                                                        */ 
/*                                                                      */ 
/*  The parameters needed to run this process are:                      */ 
/*    (1)   Input Dataset Name                                          */ 
/*    (2)   Output Dataset Name                                         */ 
/*                                                                      */ 
/*----------------------------------------------------------------------*/ 
TRACE N 
ADDRESS TSO 

ARG Args 
PARSE UPPER VAR Args iFileName oFileName . 
IF oFileName = '' THEN DO 
  "CLEAR" 
  DO i = 1 TO SOURCELINE() 
     IF SUBSTR(SOURCELINE(i), 1, 2) = '/*' THEN 
        SAY SOURCELINE(i) 
     ELSE 
        LEAVE i 
     END 
  SAY "" 
  EXIT 
  END 

IF LISTDSI(iFileName) <> 0 THEN DO 
   SAY "Invalid Input File Name in Parameter #1" 
   EXIT 
   END 
"ALLOC DDN(iFile) SHR DSN("iFileName") REUSE" 

IF LISTDSI(oFileName) = 0 THEN 
  "ALLOC DDN(oFile) OLD DSN("oFileName") REUSE" 
ELSE 
  "ALLOC DDN(oFile) NEW SPACE(20,20) TRACKS LRECL(512)", 
        "DSN("oFileName") REUSE" 

DO 1 
  "EXECIO 1 DISKR iFile (STEM Line.)" 
  IF Line.0 = 0 THEN 
    LEAVE 
  CALL Parse_Line 
END 

"EXECIO 0 DISKR iFile (FINIS)" 
"EXECIO "QUEUED()" DISKW oFile (FINIS)" 
"FREE DDN(iFile, oFile)" 
EXIT 0 

/*---------------------------------------------------------------------*/ 
Parse_Line: 
/*---------------------------------------------------------------------*/ 
   WorkLine = '' 
   Parens = 0 
   Breaks = FALSE 
   Line.1 = STRIP(Line.1, 'B') 
   DO WHILE WORDS(Line.1) > 0 
      KeyWord = WORD(Line.1, 1) 
      UPPER KeyWord 
      SELECT 
        WHEN KeyWord = '/*' THEN DO 
          WorkLine = WorkLine" "Pull_Line(WORDPOS('*/', Line.1)) 
          CALL Write_Line 
          END 
        WHEN KeyWord = 'LOCKING' THEN DO 
          Break = FALSE 
          IF WorkLine <> "" THEN 
             CALL Write_Line 
          WorkLine = WorkLine""Pull_Line(1) 
          END 
        WHEN KeyWord = 'SELECT' THEN DO 
          Break = TRUE 
          IF WorkLine <> "" THEN 
             CALL Write_Line 
          WorkLine = WorkLine""Pull_Line(1) 
          END 
        WHEN KeyWord = 'SEL' THEN DO 
          Break = TRUE 
          IF WorkLine <> "" THEN 
             CALL Write_Line 
          WorkLine = WorkLine""Pull_Line(1) 
          END 
        WHEN KeyWord = 'FROM' THEN DO 
          Break = TRUE 
          IF WorkLine <> "" THEN 
             CALL Write_FROM 
          WorkLine = WorkLine""Pull_Line(1) 
          END 
        WHEN KeyWord = 'WHERE' THEN DO 
          Break = FALSE 
          IF WorkLine <> "" THEN 
             CALL Write_Line 
          WorkLine = WorkLine""Pull_Line(1) 
          END 
        WHEN KeyWord = 'AND' THEN DO 
          Break = FALSE 
          IF WorkLine <> "" THEN 
             CALL Write_Line 
          WorkLine = WorkLine""Pull_Line(1) 
          END 
        WHEN KeyWord = 'OR' THEN DO 
          Break = FALSE 
          IF WorkLine <> "" THEN 
             CALL Write_Line 
          WorkLine = WorkLine""Pull_Line(1) 
          END 
        WHEN KeyWord = 'HAVING' THEN DO 
          Break = FALSE 
          IF WorkLine <> "" THEN 
             CALL Write_Line 
          WorkLine = WorkLine""Pull_Line(1) 
          END 
        WHEN KeyWord = 'WITH' THEN DO 
          Break = FALSE 
          IF WorkLine <> "" THEN 
             CALL Write_Line 
          WorkLine = WorkLine""Pull_Line(1) 
          END 
        WHEN KeyWord = 'GROUP' THEN DO 
          Break = FALSE 
          IF WorkLine <> "" THEN 
             CALL Write_Line 
          WorkLine = WorkLine""Pull_Line(1) 
          END 
        WHEN KeyWord = 'ORDER' THEN DO 
          Break = FALSE 
          IF WorkLine <> "" THEN 
             CALL Write_Line 
          WorkLine = WorkLine""Pull_Line(1) 
          END 
        OTHERWISE 
          WorkLine = WorkLine""Pull_Line(1) 
        END 
      END 
   CALL Write_Line 
   "EXECIO "QUEUED()" DISKW oFile (FINIS)" 
   RETURN 

/*---------------------------------------------------------------------*/ 
Pull_Line:    ARG WordPos 
/*---------------------------------------------------------------------*/ 
   IF LEFT(WORD(Line.1, WordPos), 1) = ',' THEN DO 
      CALL Write_Line 
      END 
   WrdPos = INDEX(Line.1, WORD(Line.1, WordPos)) 
   WrdTxt = SUBSTR(Line.1, 1, WrdPos+LENGTH(WORD(Line.1, WordPos))-1) 
   Line.1 = SUBSTR(Line.1, WrdPos+LENGTH(WORD(Line.1, WordPos))+1, LENGTH(Line.1)) 
   IF RIGHT(WORD(Line.1, WordPos), 1) = ',' THEN DO 
      CALL Write_Line 
      WrdTxt = '' 
      END 
   RETURN WrdTxt 

/*---------------------------------------------------------------------*/ 
Write_Line: 
/*---------------------------------------------------------------------*/ 
   QUEUE WorkLine 
   SAY WorkLine 
   WorkLine = '' 
   RETURN 
